==> openejb-jee-4.7.5-sources.jar: org/apache/openejb/jee/was/v6/common/MessageDestinationUsageEnum.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements.  See the NOTICE file distributed with
 *   this work for additional information regarding copyright ownership.
 *   The ASF licenses this file to You under the Apache License, Version 2.0
 *   (the "License"); you may not use this file except in compliance with
 *   the License.  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */
package org.apache.openejb.jee.was.v6.common;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;

/**
 * <p/>
 * Java class for MessageDestinationUsageType.
 * <p/>
 * <p/>
 * The following schema fragment specifies the expected content contained within
 * this class.
 * <p/>
 * <p/>
 * <pre>
 * &lt;simpleType name="MessageDestinationUsageType">
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}NCName">
 *     &lt;enumeration value="Consumes"/>
 *     &lt;enumeration value="Produces"/>
 *     &lt;enumeration value="ConsumesProduces"/>
 *   &lt;/restriction>
 * &lt;/simpleType>
 * </pre>
 */
@XmlEnum
public enum MessageDestinationUsageEnum {

    @XmlEnumValue("Consumes")
    CONSUMES("Consumes"), @XmlEnumValue("Produces")
    PRODUCES("Produces"), @XmlEnumValue("ConsumesProduces")
    CONSUMES_PRODUCES("ConsumesProduces");
    private final String value;

    MessageDestinationUsageEnum(final String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static MessageDestinationUsageEnum fromValue(final String v) {
        for (final MessageDestinationUsageEnum c : MessageDestinationUsageEnum
            .values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v.toString());
    }

}

==> openejb-jee-8.0.14-sources.jar: org/apache/openejb/jee/was/v6/common/MessageDestinationUsageEnum.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements.  See the NOTICE file distributed with
 *   this work for additional information regarding copyright ownership.
 *   The ASF licenses this file to You under the Apache License, Version 2.0
 *   (the "License"); you may not use this file except in compliance with
 *   the License.  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */
package org.apache.openejb.jee.was.v6.common;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;

/**
 *
 * Java class for MessageDestinationUsageType.
 *
 *
 * The following schema fragment specifies the expected content contained within
 * this class.
 *
 *
 * <pre>
 * &lt;simpleType name="MessageDestinationUsageType"&gt;
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}NCName"&gt;
 *     &lt;enumeration value="Consumes"/&gt;
 *     &lt;enumeration value="Produces"/&gt;
 *     &lt;enumeration value="ConsumesProduces"/&gt;
 *   &lt;/restriction&gt;
 * &lt;/simpleType&gt;
 * </pre>
 */
@XmlEnum
public enum MessageDestinationUsageEnum {

    @XmlEnumValue("Consumes")
    CONSUMES("Consumes"), @XmlEnumValue("Produces")
    PRODUCES("Produces"), @XmlEnumValue("ConsumesProduces")
    CONSUMES_PRODUCES("ConsumesProduces");
    private final String value;

    MessageDestinationUsageEnum(final String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static MessageDestinationUsageEnum fromValue(final String v) {
        for (final MessageDestinationUsageEnum c : MessageDestinationUsageEnum
            .values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v.toString());
    }

}
